@@ -16,6 +16,7 @@ mod use_queue;
 mod use_raf;
 mod use_raf_state;
 mod use_scroll;
+mod use_scrolling;
 mod use_session_storage;
 mod use_set;
 mod use_timeout;
@@ -44,6 +45,7 @@ pub use use_queue::*;
 pub use use_raf::*;
 pub use use_raf_state::*;
 pub use use_scroll::*;
+pub use use_scrolling::*;
 pub use use_session_storage::*;
 pub use use_set::*;
 pub use use_timeout::*;
